@@ -1,2 +1,2 @@
 from .core import (Executer, Recorder, RecorderExecuter, start_executing,
-                   start_recording)
+                   start_recording, write)
